Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Secrets ¶
type Secrets struct {
ConfigName string `json:"ConfigName"`
Records []struct {
Key string `json:"Key"`
Value string `json:"Value"`
} `json:"Records"`
}
func Initialize ¶
Initialize - accepts either a path to a file or a path to a GCP Secrets entry
func InitializeFromEnvironment ¶
InitializeFromEnvironment - accepts environment variable name that holds either a path to a file or a path to a GCP Secrets entry
Click to show internal directories.
Click to hide internal directories.