Documentation
¶
Index ¶
- func DecodeInteger(key string) int
- func EncodeInteger(key int) string
- func FileExists(filename string) bool
- func Filter(vs []string, f func(string) bool) []string
- func IntSliceToCSV(ns []int) string
- func JSONMarshalNoEscape(t interface{}) ([]byte, error)
- func StringsDiff(a, b []string) (diff []string)
- func UniqueInts(input []int) []int
- type CustomLogFormat
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DecodeInteger ¶ added in v0.2.9
func EncodeInteger ¶ added in v0.2.9
func Filter ¶
Filter - accept slice of string, return slice with only those entries that return true to passed function
func IntSliceToCSV ¶
IntSliceToCSV - convert a slice of integers into a CSV string
func JSONMarshalNoEscape ¶
func StringsDiff ¶ added in v0.2.10
StringsDiff - set difference, result is A - B
func UniqueInts ¶
UniqueInts returns a unique subset of the int slice provided.
Types ¶
type CustomLogFormat ¶ added in v0.2.3
type CustomLogFormat struct{}
Click to show internal directories.
Click to hide internal directories.